#!/bin/bash

# Admin menu : to be deployed on each MediaServer
# Customer should arrive on it after each SSH connexion with login admin

BACKTITLE='MediaServer Deployement'

## Load already set up parameters
MS_IP0=$(grep address /etc/network/interfaces | awk '{print$2}')
MS_NETMASK0=$(grep netmask /etc/network/interfaces | awk '{print$2}')
MS_GATEWAY0=$(grep gateway /etc/network/interfaces | awk '{print$2}')
MS_DNS10=$(grep nameserver /etc/resolv.conf | head -1 | awk '{print$2}')
MS_DNS20=$(grep nameserver /etc/resolv.conf | tail -1 | awk '{print$2}')
MS_NTP0=$(grep ^server /etc/ntp.conf | tail -1 | awk '{print$2}')
MS_VHOST0=$(grep server_name /etc/nginx/sites-available/mediaserver-msuser.conf | head -1 | awk '{print$2}' | awk -F ";" '{print$1}')
MS_CMVHOST0=$(grep server_name /etc/nginx/sites-available/skyreach.conf | head -1 | awk '{print$2}' | awk -F ";" '{print$1}')
MS_MONVHOST0=$(grep server_name /etc/nginx/sites-available/msmonitor.conf | head -1 | awk '{print$2}' | awk -F ";" '{print$1}')


## Screens
dialog --backtitle "${BACKTITLE}" --title "Perform customization" --yesno "Welcome to UbiCast MediaServer customization tool." 8 70

if [ $? != 0 ]
then
dialog --backtitle "${BACKTITLE}" --title "Perform customization" --msgbox "MediaServer deployement cancelled." 8 70
exit
fi

# Network parameters
MS_IP=$(dialog --backtitle "${BACKTITLE}" --title "Network configuration"  --inputbox "MediaServer IP ?" 8 50 ${MS_IP0} --output-fd 1)
MS_NETMASK=$(dialog --backtitle "${BACKTITLE}" --title "Network configuration"  --inputbox "Netmask ?" 8 50 ${MS_NETMASK0} --output-fd 1)
MS_GATEWAY=$(dialog --backtitle "${BACKTITLE}" --title "Network configuration"  --inputbox "Gateway ?" 8 50 ${MS_GATEWAY0} --output-fd 1)
MS_DNS1=$(dialog --backtitle "${BACKTITLE}" --title "Network configuration"  --inputbox "Main DNS ?" 8 50 ${MS_DNS10} --output-fd 1)
MS_DNS2=$(dialog --backtitle "${BACKTITLE}" --title "Network configuration"  --inputbox "Secondary DNS ?" 8 50 ${MS_DNS20} --output-fd 1)
MS_NTP=$(dialog --backtitle "${BACKTITLE}" --title "Network configuration"  --inputbox "NTP server ?" 8 50 ${MS_NTP0} --output-fd 1)

# vhosts
MS_VHOST=$(dialog --backtitle "${BACKTITLE}" --title "Webserver configuration"  --inputbox "MS main URL (ie mediaserver.example.com)" 8 50 ${MS_VHOST0} --output-fd 1)
MS_CMVHOST=$(dialog --backtitle "${BACKTITLE}" --title "Webserver configuration"  --inputbox "CampusManager URL (ie campusmanager.example.com)" 8 60 ${MS_CMVHOST0} --output-fd 1)
MS_MONVHOST=$(dialog --backtitle "${BACKTITLE}" --title "Webserver configuration"  --inputbox "Monitor application URL (ie monitor-mediaserver.example.com)" 8 70 ${MS_MONVHOST0} --output-fd 1)

## Server configuration
# IP
sudo sed -i "s@address .*@address ${MS_IP}@" /etc/network/interfaces
sudo sed -i "s@netmask .*@netmask ${MS_NETMASK}@" /etc/network/interfaces
sudo sed -i "s@gateway .*@gateway ${MS_GATEWAY}@" /etc/network/interfaces

# DNS
sudo chown msinstall:root /etc/resolv.conf
sudo echo "nameserver ${MS_DNS1}" > /etc/resolv.conf
# test DNS2
if ( test -z ${MS_DNS2} )
then
echo "no 2nd DNS"
else
sudo echo "nameserver ${MS_DNS2}" >> /etc/resolv.conf
fi
sudo chown root:root /etc/resolv.conf

# NTP
sudo chown msinstall:root /etc/ntp.conf
sudo sed -i "s@^server .*@@" /etc/ntp.conf
sudo echo ${MS_NTP} >> /etc/ntp.conf
sudo chown root:root /etc/ntp.conf

# webserver
# ms
sudo sed -i "s@server_name .*@server_name ${MS_VHOST};@" /etc/nginx/sites-available/mediaserver-msuser.conf
# cm
sudo sed -i "s@server_name .*@server_name ${MS_CMVHOST};@" /etc/nginx/sites-available/skyreach.conf
# monitor
sudo sed -i "s@server_name .*@server_name ${MS_MONVHOST};@" /etc/nginx/sites-available/msmonitor.conf

## Customization complete

dialog --backtitle "${BACKTITLE}" --title "Customization complete" --msgbox "Congratulations, your MS is now configured.
Press enter to reboot." 8 50

sudo reboot
